import { SourceType, UserOptions } from 'wind-gl-core';
export { DecodeType, ImageSource, LayerSourceType, MaskType, RenderFrom, RenderType, TileID, TileSource, TimelineSource, configDeps } from 'wind-gl-core';
import * as _sakitam_gis_vis_engine from '@sakitam-gis/vis-engine';
import { Matrix4, Scene, OrthographicCamera, PerspectiveCamera, Renderer } from '@sakitam-gis/vis-engine';

declare class CameraSync {
    worldMatrix: Matrix4;
    mercatorMatrix: Matrix4;
    labelPlaneMatrix: Matrix4;
    glCoordMatrix: Matrix4;
    map: any;
    scene: Scene;
    camera: OrthographicCamera | PerspectiveCamera;
    halfFov: number;
    cameraToCenterDistance: number;
    acuteAngle: number;
    cameraTranslateZ: number;
    constructor(map: any, cameraType: any, scene: any);
    setup(): void;
    update(): void;
}

interface LayerOptions extends UserOptions {
    renderingMode?: '2d' | '3d';
}
declare class Layer {
    gl: WebGLRenderingContext | WebGL2RenderingContext | null;
    map: WithNull<maplibregl.Map>;
    id: string;
    type: string;
    renderingMode: '2d' | '3d';
    sync: CameraSync;
    scene: Scene;
    planeCamera: OrthographicCamera;
    renderer: Renderer;
    private options;
    private source;
    private layer;
    constructor(id: string, source: SourceType, options?: LayerOptions);
    get camera(): OrthographicCamera | _sakitam_gis_vis_engine.PerspectiveCamera;
    update(): void;
    moveStart(): void;
    moveEnd(): void;
    handleResize(): void;
    handleZoom(): void;
    updateOptions(options: Partial<LayerOptions>): void;
    getMask(): any;
    private processMask;
    setMask(mask: any): void;
    onAdd(m: maplibregl.Map, gl: WebGLRenderingContext): void;
    calcWrappedWorlds(): number[];
    onRemove(): void;
    prerender(): void;
    picker(coordinates: any): Promise<any>;
    render(): void;
}

export { Layer };
